@@ -5,9 +5,6 @@ package Parley::Schema::Thread;
 use strict;
 use warnings;
 
-use Parley::Version;  our $VERSION = $Parley::VERSION;
-use DateTime::Format::Pg;
-
 use base 'DBIx::Class';
 
 __PACKAGE__->load_components("PK::Auto", "Core");
